@@ -69,6 +69,7 @@ from .usecases.color_detection import ColorDetectionConfig
 from .usecases.fire_detection import FireSmokeUseCase, FireSmokeConfig
 from .usecases.license_plate_detection import LicensePlateConfig
 from .usecases.pothole_segmentation import PotholeConfig
+from .usecases.wound_segmentation import WoundConfig, WoundSegmentationUseCase
 from .usecases.face_emotion import FaceEmotionConfig
 from .usecases.parking_space_detection import ParkingSpaceConfig
 from .usecases.underwater_pollution_detection import UnderwaterPlasticConfig
@@ -76,6 +77,8 @@ from .usecases.pedestrian_detection import PedestrianDetectionConfig
 from .usecases.age_detection import AgeDetectionConfig
 from .usecases.mask_detection import MaskDetectionConfig
 from .usecases.chicken_pose_detection import ChickenPoseDetectionConfig
+from .usecases.field_mapping import FieldMappingConfig, FieldMappingUseCase
+from .usecases.leaf_disease import LeafDiseaseDetectionConfig, LeafDiseaseDetectionUseCase
 
 
 from .usecases.weld_defect_detection import WeldDefectConfig
@@ -95,6 +98,7 @@ from .usecases.gender_detection import GenderDetectionConfig
 from .usecases.concrete_crack_detection import ConcreteCrackConfig
 from .usecases.fashion_detection import FashionDetectionConfig, FashionDetectionUseCase
 from .usecases.shelf_inventory_detection import ShelfInventoryConfig
+from .usecases.road_lane_detection import LaneDetectionConfig
 
 from .usecases.warehouse_object_segmentation import WarehouseObjectConfig
 from .usecases.shopping_cart_analysis import ShoppingCartConfig
@@ -104,6 +108,8 @@ from .usecases.shoplifting_detection import ShopliftingDetectionConfig, Shoplift
 from .usecases.defect_detection_products import BottleDefectUseCase, BottleDefectConfig
 from .usecases.assembly_line_detection import AssemblyLineUseCase, AssemblyLineConfig
 from .usecases.car_part_segmentation import CarPartSegmentationUseCase, CarPartSegmentationConfig
+from .usecases.windmill_maintenance import WindmillMaintenanceUseCase, WindmillMaintenanceConfig
+from .usecases.flower_segmentation import FlowerUseCase, FlowerConfig
 
 # Use case implementations
 from .usecases import (
@@ -124,6 +130,7 @@ from .usecases import (
     FaceEmotionUseCase,
     UnderwaterPlasticUseCase,
     PedestrianDetectionUseCase,
+    WoundSegmentationUseCase,
     AgeDetectionUseCase,
     BananaMonitoringUseCase,
     WeldDefectUseCase,
@@ -132,6 +139,7 @@ from .usecases import (
     EmergencyVehicleUseCase,
     SolarPanelUseCase,
     ChickenPoseDetectionUseCase,
+    LeafDiseaseDetectionUseCase,
     TheftDetectionUseCase,
     TrafficSignMonitoringUseCase,
     CropWeedDetectionUseCase,
@@ -144,10 +152,13 @@ from .usecases import (
     ShoppingCartUseCase,
     BottleDefectUseCase,
     AssemblyLineUseCase,
+    FieldMappingUseCase,
     AntiSpoofingDetectionUseCase,
     ShelfInventoryUseCase,
-
-    CarPartSegmentationUseCase
+    LaneDetectionUseCase,
+    WindmillMaintenanceUseCase,
+    CarPartSegmentationUseCase,
+    FlowerUseCase,
 )
 
 # Register use cases automatically
@@ -173,6 +184,7 @@ _chicken_pose_detection = ChickenPoseDetectionUseCase()
 _theft_detection = TheftDetectionUseCase()
 _traffic_sign_monitoring = TrafficSignMonitoringUseCase()
 _shelf_inventory = ShelfInventoryUseCase()
+_lane_detection = LaneDetectionUseCase()
 
 _weld_defect_detection = WeldDefectUseCase()
 _pricetag_detection = PriceTagUseCase()
@@ -197,6 +209,13 @@ _defect_detection_products = BottleDefectUseCase()
 _assembly_line_detection = AssemblyLineUseCase()
 _car_part_segmentation = CarPartSegmentationUseCase()
 
+_windmill_maintenance = WindmillMaintenanceUseCase()
+
+_field_mapping = FieldMappingUseCase()
+_wound_segmentation = WoundSegmentationUseCase()
+_leaf_disease = LeafDiseaseDetectionUseCase()
+_flower_segmentation = FlowerUseCase()
+
 registry.register_use_case(_people_counting.category, _people_counting.name, PeopleCountingUseCase)
 registry.register_use_case(_customer_service.category, _customer_service.name, CustomerServiceUseCase)
 registry.register_use_case(_advanced_customer_service.category, _advanced_customer_service.name, AdvancedCustomerServiceUseCase)
@@ -223,6 +242,7 @@ registry.register_use_case(_traffic_sign_monitoring.category, _traffic_sign_moni
 registry.register_use_case(_gender_detection.category, _gender_detection.name, GenderDetectionUseCase)
 registry.register_use_case(_anti_spoofing_detection.category, _anti_spoofing_detection.name, AntiSpoofingDetectionUseCase)
 registry.register_use_case(_shelf_inventory.category, _shelf_inventory.name, ShelfInventoryUseCase)
+registry.register_use_case(_lane_detection.category, _lane_detection.name, LaneDetectionUseCase)
 
 registry.register_use_case(_car_damage.category, _car_damage.name, CarDamageDetectionUseCase)
 registry.register_use_case(_distracted_driver.category, _distracted_driver.name, DistractedDriverUseCase)
@@ -244,6 +264,13 @@ registry.register_use_case(_defect_detection_products.category, _defect_detectio
 registry.register_use_case(_assembly_line_detection.category, _assembly_line_detection.name, AssemblyLineUseCase)
 registry.register_use_case(_car_part_segmentation.category, _car_part_segmentation.name, CarPartSegmentationUseCase)
 
+registry.register_use_case(_windmill_maintenance.category, _windmill_maintenance.name, WindmillMaintenanceUseCase)
+
+registry.register_use_case(_field_mapping.category, _field_mapping.name, FieldMappingUseCase)
+registry.register_use_case(_wound_segmentation.category, _wound_segmentation.name,WoundSegmentationUseCase)
+registry.register_use_case(_leaf_disease.category, _leaf_disease.name, LeafDiseaseDetectionUseCase)
+registry.register_use_case(_flower_segmentation.category, _flower_segmentation.name, FlowerUseCase)
+
 # Utility functions - organized by category
 from .utils import (  # noqa: E402
     # Geometry utilities
@@ -379,6 +406,9 @@ __all__ = [
     'MaskDetectionConfig',
     'ShopliftingDetectionConfig',
     'CarDamageConfig',
+    'LeafDiseaseDetectionConfig',
+    'WoundConfig',
+    'FieldMappingConfig',
     'ParkingSpaceConfig',
     'PotholeConfig',
     'VehicleMonitoringConfig',
@@ -416,6 +446,9 @@ __all__ = [
     'AntiSpoofingDetectionConfig',
     'ShelfInventoryConfig',
     'CarPartSegmentationConfig',
+    'LaneDetectionConfig',
+    'WindmillMaintenanceConfig',
+    'FlowerConfig',
 
     # Use case classes
     'PeopleCountingUseCase',
@@ -426,12 +459,14 @@ __all__ = [
     'ColorDetectionUseCase',
     'PPEComplianceUseCase',
     'PotholeSegmentationUseCase',
+    'WoundSegmentationUseCase',
     'MaskDetectionUseCase',
     'VehicleMonitoringUseCase',
     'FireSmokeUseCase',
     'CarDamageDetectionUseCase',
     'ParkingSpaceUseCase',
     'FlareAnalysisUseCase',
+    'FieldMappingUseCase',
     'FaceEmotionUseCase',
     'UnderwaterPlasticUseCase',
     'PedestrianDetectionUseCase',
@@ -439,6 +474,7 @@ __all__ = [
     'ShopliftingDetectionUseCase',
     'WeldDefectUseCase',
     'BananaMonitoringUseCase',
+    'LeafDiseaseDetectionUseCase',
     'PriceTagUseCase',
     'DistractedDriverUseCase',
     'EmergencyVehicleUseCase',
@@ -460,6 +496,9 @@ __all__ = [
     'AssemblyLineUseCase',
     'AntiSpoofingDetectionUseCase',
     'CarPartSegmentationUseCase',
+    'LaneDetectionUseCase',
+    'WindmillMaintenanceUseCase',
+    'FlowerUseCase'
     
     # Base classes for extension
     'BaseProcessor',
