@@ -48,6 +48,15 @@ from ..usecases.shoplifting_detection import ShopliftingDetectionConfig, Shoplif
 from ..usecases.defect_detection_products import BottleDefectUseCase, BottleDefectConfig
 from ..usecases.shelf_inventory_detection import ShelfInventoryConfig,ShelfInventoryUseCase
 from ..usecases.car_part_segmentation import CarPartSegmentationUseCase, CarPartSegmentationConfig
+from ..usecases.road_lane_detection import LaneDetectionUseCase , LaneDetectionConfig
+
+from ..usecases.windmill_maintenance import WindmillMaintenanceUseCase, WindmillMaintenanceConfig
+
+from ..usecases.field_mapping import FieldMappingConfig, FieldMappingUseCase
+from ..usecases.wound_segmentation import WoundConfig,WoundSegmentationUseCase
+from ..usecases.leaf_disease import LeafDiseaseDetectionConfig, LeafDiseaseDetectionUseCase
+from ..usecases.flower_segmentation import FlowerUseCase, FlowerConfig
+
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -55,14 +64,18 @@ __all__ = [
     'BananaMonitoringUseCase',
     'AdvancedCustomerServiceUseCase',
     'BasicCountingTrackingUseCase',
+    'FieldMappingUseCase',
     'LicensePlateUseCase',
     'ColorDetectionUseCase',
+    'LeafDiseaseDetectionUseCase',
     'PPEComplianceUseCase',
     'VehicleMonitoringUseCase',
     'FireSmokeUseCase',
     'PotholeSegmentationUseCase',
     'AntiSpoofingDetectionUseCase',
+    'WoundSegmentationUseCase',
     'ShelfInventoryUseCase',
+    'LaneDetectionUseCase',
 
     'ShopliftingDetectionUseCase',
     'ParkingSpaceUseCase',
@@ -92,6 +105,8 @@ __all__ = [
     'BottleDefectUseCase',
     'AssemblyLineUseCase',
     'CarPartSegmentationUseCase',
+    'WindmillMaintenanceUseCase',
+    'FlowerUseCase',
 
 
 
@@ -105,12 +120,14 @@ __all__ = [
     'LicensePlateConfig',
     'ColorDetectionConfig',
     'VehicleMonitoringConfig',
+    'WoundConfig',
     'ParkingSpaceConfig',
     'MaskDetectionConfig',
     'FireSmokeConfig',
     'ShopliftingDetectionConfig',
     'CarDamageConfig',
     'FlareAnalysisConfig',
+    'FieldMappingConfig',
     'FaceEmotionConfig',
     'UnderwaterPlasticConfig',
     'PedestrianDetectionConfig',
@@ -127,6 +144,7 @@ __all__ = [
     'ChildMonitoringConfig',
     'GenderDetectionConfig',
     'WeaponDetectionConfig',
+    'LeafDiseaseDetectionConfig',
     'ConcreteCrackConfig',
     'FashionDetectionConfig',
     'WarehouseObjectConfig',
@@ -136,4 +154,7 @@ __all__ = [
     'AntiSpoofingDetectionConfig',
     'ShelfInventoryConfig',
     'CarPartSegmentationConfig',
+    'LaneDetectionConfig',
+    'WindmillMaintenanceConfig',
+    'FlowerConfig',
 ]
