@@ -38,11 +38,14 @@ from .usecases import (
     VehicleMonitoringUseCase,
     ShopliftingDetectionUseCase,
     BananaMonitoringUseCase,
+    FieldMappingUseCase,
     MaskDetectionUseCase,
     CarDamageDetectionUseCase,
+    LeafDiseaseDetectionUseCase,
     FireSmokeUseCase,
     ShopliftingDetectionConfig,
     FlareAnalysisUseCase,
+    WoundSegmentationUseCase,
     ParkingSpaceUseCase,
     FaceEmotionUseCase,
     UnderwaterPlasticUseCase,
@@ -52,6 +55,8 @@ from .usecases import (
     TrafficSignMonitoringUseCase,
     AntiSpoofingDetectionUseCase,
     ShelfInventoryUseCase,
+    LaneDetectionUseCase,
+
 
 
     AgeDetectionUseCase,
@@ -73,6 +78,8 @@ from .usecases import (
     BottleDefectUseCase,
     AssemblyLineUseCase,
     CarPartSegmentationUseCase,
+    WindmillMaintenanceUseCase,
+    FlowerUseCase,
 
 )
 
@@ -149,6 +156,7 @@ class PostProcessor:
         registry.register_use_case("traffic", "traffic_sign_monitoring", TrafficSignMonitoringUseCase)
         registry.register_use_case("security", "anti_spoofing_detection", AntiSpoofingDetectionUseCase)
         registry.register_use_case("retail", "shelf_inventory", ShelfInventoryUseCase)
+        registry.register_use_case("traffic", "lane_detection", LaneDetectionUseCase)
         
         registry.register_use_case("hazard", "fire_smoke_detection", FireSmokeUseCase)
         registry.register_use_case("flare_detection", "flare_analysis", FlareAnalysisUseCase)
@@ -178,7 +186,15 @@ class PostProcessor:
         registry.register_use_case("retail", "defect_detection_products", BottleDefectUseCase)
         registry.register_use_case("manufacturing", "assembly_line_detection", AssemblyLineUseCase)
         registry.register_use_case("automobile", "car_part_segmentation", CarPartSegmentationUseCase)
+
+        registry.register_use_case("manufacturing", "windmill_maintenance", WindmillMaintenanceUseCase)
+
+        registry.register_use_case("infrastructure", "field_mapping", FieldMappingUseCase)
+        registry.register_use_case("medical", "wound_segmentation", WoundSegmentationUseCase)
+        registry.register_use_case("agriculture", "leaf_disease_detection", LeafDiseaseDetectionUseCase)
+        registry.register_use_case("agriculture", "flower_segmentation", FlowerUseCase)
         
+
         logger.debug("Registered use cases with registry")
     
     def _generate_cache_key(self, config: BaseConfig, stream_key: Optional[str] = None) -> str:
@@ -304,6 +320,20 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, ConcreteCrackUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, LaneDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+
+            elif isinstance(use_case, WindmillMaintenanceUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+
+            elif isinstance(use_case, FieldMappingUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, WoundSegmentationUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, LeafDiseaseDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, FlowerUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
 
             else:
                 result = use_case.process(data, parsed_config, context, stream_info)
